@@ -8,6 +8,7 @@ NULL
 #'
 #' @export
 #' @param x a date-time object
+#' @param value numeric value to be assigned
 #' @keywords utilities manip chron methods
 #' @return the minutes element of x as a decimal number
 #' @examples
@@ -16,27 +17,52 @@ NULL
 #' minute(x) <- 1
 #' minute(x) <- 61
 #' minute(x) > 2
-minute <- function(x)
+minute <- function(x) {
   UseMethod("minute")
+}
 
 #' @export
-minute.default <- function(x)
+minute.default <- function(x) {
   as.POSIXlt(x, tz = tz(x))$min
+}
 
 #' @export
-minute.Period <- function(x)
+minute.Period <- function(x) {
   slot(x, "minute")
+}
 
 #' @rdname minute
-#' @param value numeric value to be assigned
 #' @export
-"minute<-" <- function(x, value)
-  x <- x + minutes(value - minute(x))
+setGeneric("minute<-",
+  function (x, value) standardGeneric("minute<-"),
+  useAsDefault = function(x, value) {
+    y <- update_datetime(as.POSIXct(x), minutes = value)
+    reclass_date(y, x)
+  }
+)
 
-setGeneric("minute<-")
+#' @export
+setMethod("minute<-", "Duration", function(x, value) {
+  x <- x + minutes(value - minute(x))
+})
 
 #' @export
 setMethod("minute<-", signature("Period"), function(x, value) {
   slot(x, "minute") <- value
   x
 })
+
+#' @export
+setMethod("minute<-", "Interval", function(x, value) {
+  x <- x + minutes(value - minute(x))
+})
+
+#' @export
+setMethod("minute<-", "POSIXt", function(x, value) {
+  update_datetime(x, minutes = value)
+})
+
+#' @export
+setMethod("minute<-", "Date", function(x, value) {
+  update_datetime(x, minutes = value)
+})
